summaryrefslogtreecommitdiffstats
path: root/karm/karmstorage.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit36a36a5c1015aa0d03f4515c401e907ddb9d6291 (patch)
tree0212ba6d2c749043134005a41f2bd0379619d40f /karm/karmstorage.h
parent4c6f8d69e2d1501837affb472c4eb8fec4462240 (diff)
downloadtdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.tar.gz
tdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'karm/karmstorage.h')
-rw-r--r--karm/karmstorage.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/karm/karmstorage.h b/karm/karmstorage.h
index 40c574d7..65caafd7 100644
--- a/karm/karmstorage.h
+++ b/karm/karmstorage.h
@@ -132,7 +132,7 @@ class KarmStorage
* Read tasks and their total times from a text file (legacy storage).
*
* This reads from one of the two legacy file formats. In this version,
* the tqparent task times do not include the sum of all their tqchildren's
* times.
*
* The format of the file is zero or more lines of:
@@ -266,15 +266,15 @@ class KarmStorage
* Add this task from iCalendar file.
*
* Create a new KCal::Todo object and load with task information. If
* tqparent is not zero, then set the RELATED-TO attribute for this Todo.
*
* @param task The task to be removed.
* @param tqparent The tqparent of this task. Must have a uid() that is in
* the existing calendar. If zero, this task is considered a root task.
* @return The unique ID for the new VTODO. Return an null TQString if
* there was an error creating the new calendar object.
*/
- TQString addTask(const Task* task, const Task* tqparent);
+ TQString addTask(const Task* task, const Task* parent);
/**
* Check if the iCalendar file currently loaded has any Todos in it.
@@ -132,7 +132,7 @@ class KarmStorage
*
* This reads from one of the two legacy file formats. In this version,
- * the tqparent task times do not include the sum of all their tqchildren's
+ * the parent task times do not include the sum of all their tqchildren's
* times.
*
@@ -266,15 +266,15 @@ class KarmStorage
*
* Create a new KCal::Todo object and load with task information. If
- * tqparent is not zero, then set the RELATED-TO attribute for this Todo.
+ * parent is not zero, then set the RELATED-TO attribute for this Todo.
*
* @param task The task to be removed.
@@ -266,15 +266,15 @@ class KarmStorage
*
* @param task The task to be removed.
- * @param tqparent The tqparent of this task. Must have a uid() that is in
+ * @param parent The parent of this task. Must have a uid() that is in
* the existing calendar. If zero, this task is considered a root task.
* @return The unique ID for the new VTODO. Return an null TQString if